==> isoquant-3.5.1-hdfd78af_0.tar.bz2: share/isoquant-3.5.1-0/build_env_setup.sh <==
export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export ARCH="64"
export PREFIX="/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export BUILD_PREFIX="/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export SYS_PREFIX="/opt/conda"
export SYS_PYTHON="/opt/conda/bin/python"
export SUBDIR="linux-64"
export build_platform="linux-64"
export SRC_DIR="/opt/conda/conda-bld/isoquant_1724750465066/work"
export ROOT="/opt/conda"
export CONDA_PY="312"
export PY3K="1"
export PY_VER="3.12"
export STDLIB_DIR="/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.12"
export SP_DIR="/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.12/site-packages"
export NPY_VER="1.26"
export CONDA_NPY="126"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.32"
export CONDA_PERL="5.32"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="4.3.*"
export CONDA_R="4.3.*"
export PKG_NAME="isoquant"
export PKG_VERSION="3.5.1"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/opt/recipe"
export CPU_COUNT="2"
export LANG="C.UTF-8"
export SHLIB_EXT=".so"
export PATH="/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin:/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin:/opt/conda/bin:/opt/conda/condabin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/home/conda/bin"
export HOME="/home/conda"
export PKG_CONFIG_PATH="/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export LD_RUN_PATH="/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib"
export BUILD="x86_64-conda_cos6-linux-gnu"
export pin_run_as_build="OrderedDict([('python', {'min_pin': 'x.x', 'max_pin': 'x.x'}), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('flann', {'max_pin': 'x.x.x'}), ('graphviz', {'max_pin': 'x'}), ('libsvm', {'max_pin': 'x'}), ('netcdf-cxx4', {'max_pin': 'x.x'}), ('occt', {'max_pin': 'x.x'}), ('poppler', {'max_pin': 'x.x'}), ('vlfeat', {'max_pin': 'x.x.x'})])"
export ignore_build_only_deps="{'numpy', 'python'}"
export extend_keys="{'pin_run_as_build', 'ignore_build_only_deps', 'ignore_version', 'extend_keys'}"
export zip_keys="[['arrow_cpp', 'libarrow', 'libarrow_all'], ['c_compiler_version', 'cxx_compiler_version', 'fortran_compiler_version'], ['c_stdlib_version', 'cdt_name'], ['python', 'numpy', 'python_impl']]"
export gct="6.2.1705709074"
export libgdal="3.8"
export fortran_compiler="gfortran"
export qt_main="5.15"
export rocksdb="9.1"
export tinyxml2="10"
export cuda_compiler_version="None"
export libhwy="1.1"
export pcre2="10.43"
export tk="8.6"
export channel_sources="conda-forge,bioconda"
export lmdb="0.9.29"
export vtk="9.2.6"
export scotch="7.0.4"
export mpfr="4"
export sdl2="2"
export davix="0.8"
export libthrift="0.20.0"
export coin_or_utils="2.11"
export zlib_ng="2.0"
export uhd="4.6.0"
export readline="8"
export jpeg="9"
export libpq="16"
export libdap4="3.20.6"
export bullet_cpp="3.25"
export aws_c_event_stream="0.4.2"
export geos="3.12.1"
export libpcap="1.10"
export aws_c_mqtt="0.10.4"
export alsa_lib="1.2"
export vlfeat="0.9.21"
export tbb_devel="2021"
export qt="5.15"
export jsoncpp="1.9.5"
export libblitz="1.0.2"
export kealib="1.5"
export mumps_seq="5.7.1"
export libexactreal="4"
export bzip2="1"
export qt6_main="6.7"
export grpc_cpp="1.52"
export gf2x="1.3"
export cpu_optimization_target="nocona"
export openjpeg="2"
export libevent="2.1.12"
export libgit2="1.8"
export aom="3.8"
export postgresql_plpython="16"
export log4cxx="1.2.0"
export libsecret="0.18"
export pyqtwebengine="5.15"
export libmatio="1.5.26"
export librdkafka="2.4"
export cutensor="2"
export libsvm="332"
export libtensorflow="2.15"
export libscotch="7.0.4"
export cxx_compiler="gxx"
export VERBOSE_CM="VERBOSE=1"
export nodejs="20"
export gmp="6"
export gflags="2.2"
export libavif="1"
export openblas="0.3.*"
export libgoogle_cloud_speech_devel="2.24"
export xerces_c="3.2"
export libspatialindex="1.9.3"
export gst_plugins_base="1.22"
export msgpack_cxx="6"
export elfutils="0.191"
export coin_or_cbc="2.10"
export glpk="5.0"
export openslide="4"
export tiledb="2.23"
export pango="1.50"
export pcl="1.14.0"
export openh264="2.4.1"
export libiconv="1"
export slepc="3.21"
export libhwloc="2.10.0"
export libgoogle_cloud_discoveryengine_devel="2.24"
export libiio="0"
export xz="5"
export thrift_cpp="0.18.1"
export harfbuzz="8"
export libintervalxt="3"
export libblas="3.9 *netlib"
export freetype="2"
export glib="2"
export libsoup="3"
export aws_c_io="0.14.8"
export libjpeg_turbo="3"
export libtensorflow_cc="2.15"
export libssh2="1"
export libxml2="2"
export libwebp_base="1"
export hdf5="1.14.3"
export libraw="0.21"
export mpich="4"
export ccr="1.3"
export mimalloc="2.1.7"
export libgoogle_cloud_pubsub_devel="2.24"
export libgoogle_cloud_spanner_devel="2.24"
export libunwind="1.6"
export pulseaudio_client="17.0"
export aws_c_sdkutils="0.1.16"
export xrootd="5"
export libboost_python_devel="1.82"
export cairo="1"
export ucx="1.16.0"
export libeantic="2"
export libnetcdf="4.9.2"
export cran_mirror="https://cran.r-project.org"
export target_gobin="${PREFIX}/bin/"
export ldas_tools_framecpp="2.9"
export eclib="20231211"
export libgoogle_cloud_bigquery_devel="2.24"
export aws_c_compression="0.2.18"
export libssh="0.10"
export pyqtchart="5.15"
export pulseaudio="17.0"
export openmpi="4"
export aws_c_cal="0.6.14"
export nspr="4"
export libosqp="0.6.3"
export libarchive="3.7"
export c_compiler="gcc"
export nss="3"
export pytorch="2.1"
export krb5="1.21"
export libcint="5.5"
export c_stdlib="sysroot"
export json_c="0.17"
export arpack="3.8"
export libsqlite="3"
export rust_compiler="rust"
export fontconfig="2"
export attr="2.5"
export capnproto="1.0.2"
export aws_c_common="0.9.19"
export zlib="1.2"
export cgo_compiler="go-cgo"
export curl="8"
export wxwidgets="3.2"
export exiv2="0.28"
export libpng="1.6"
export lcms2="2"
export libv8="8.9.83"
export sdl2_net="2"
export openexr="3.2"
export libyarp="3.9.0"
export libopentelemetry_cpp="1.15"
export libmicrohttpd="1.0"
export google_cloud_cpp_common="0.25.0"
export libgoogle_cloud_automl_devel="2.24"
export abseil_cpp="20220623.0"
export x265="3.5"
export superlu_dist="8"
export libduckdb_devel="0.9.2"
export slepc4py="3.21"
export gstreamer="1.22"
export hdf4="4.2.15"
export aws_c_auth="0.7.22"
export idyntree="12"
export pyqt="5.15"
export libabseil_static="20220623.0"
export pixman="0"
export sdl2_ttf="2"
export lzo="2"
export libhugetlbfs="2"
export aws_c_http="0.8.1"
export liblapacke="3.9 *netlib"
export libflatsurf="3"
export libopenvino_dev="2024.1.0"
export bamtools="2.5.2"
export fftw="3"
export arb="2.23"
export libaec="1"
export p11_kit="0.24"
export channel_targets="bioconda main"
export libabseil="20240116"
export petsc4py="3.21"
export libsndfile="1.2"
export libdeflate="1.20"
export srm_ifce="1.24.6"
export giflib="5.2"
export dbus="1"
export VERBOSE_AT="V=1"
export target_goos="linux"
export urdfdom="4.0"
export sdl2_image="2"
export blas_impl="mkl"
export pybind11_abi="4"
export cuda_compiler="None"
export mkl="2023"
export mkl_devel="2023"
export pulseaudio_daemon="17.0"
export sdl2_mixer="2"
export libgoogle_cloud_storage_devel="2.24"
export lerc="4"
export root_base="6.28.10"
export assimp="5.3.1"
export c_blosc2="2.14"
export cfitsio="4.3.0"
export nettle="3.9"
export target_goarch="amd64"
export proj="9.3.1"
export zeromq="4.3.5"
export mpg123="1.32"
export google_cloud_cpp="2.24"
export icu="73"
export libptscotch="7.0.4"
export libuuid="2"
export libframel="8.41"
export libmed="4.1"
export zfp="1.0"
export pugixml="1.14"
export gnutls="3.7"
export libgoogle_cloud_compute_devel="2.24"
export gfal2="2.22"
export ffmpeg="6"
export libgoogle_cloud_oauth2_devel="2.24"
export zstd="1.5"
export volk="3.1"
export libgoogle_cloud_dialogflow_cx_devel="2.24"
export libffi="3.4"
export poppler="24.04"
export spdlog="1.12"
export libwebp="1"
export gnuradio_core="3.10.10"
export libidn2="2"
export ntl="11.4.3"
export dcap="2.47"
export snappy="1.2"
export aws_sdk_cpp="1.11.267"
export libcrc32c="1.1"
export libcurl="8"
export lz4_c="1.9.3"
export aws_checksums="0.1.18"
export libflint="2.9"
export target_platform="linux-64"
export singular="4.3.2.p8"
export metis="5.1.0"
export dav1d="1.2.1"
export isl="0.26"
export libtorch="2.1"
export libgoogle_cloud_dialogflow_es_devel="2.24"
export cudnn="8"
export s2n="1.4.15"
export mumps_mpi="5.7.1"
export libode="0.16.2"
export aws_crt_cpp="0.26.9"
export occt="7.7.2"
export cuda_compiler_version_min="11.8"
export orc="2.0.1"
export tbb="2021"
export libprotobuf="4.25.3"
export pari="2.15.* *_pthread"
export gsl="2.7"
export coin_or_clp="1.17"
export libgrpc="1.62"
export wcslib="8"
export ptscotch="7.0.4"
export googleapis_cpp="0.10"
export nccl="2"
export jasper="4"
export libmatio_cpp="0.2.5"
export libgoogle_cloud_aiplatform_devel="2.24"
export librsvg="2"
export libgoogle_cloud_dlp_devel="2.24"
export petsc="3.21"
export console_bridge="1.0"
export libev="4.33"
export glew="2.1"
export nlopt="2.7"
export sqlite="3"
export poco="1.13.3"
export libxsmm="1"
export libgoogle_cloud_iam_devel="2.24"
export go_compiler="go-nocgo"
export svt_av1="2.1.0"
export rdma_core="51"
export coincbc="2.10"
export libtiff="4.6"
export coin_or_osi="0.108"
export coin_or_cgl="0.60"
export imath="3.1.11"
export libcblas="3.9 *netlib"
export c_ares="1"
export expat="2"
export _libgcc_mutex="0.1 conda_forge"
export starlink_ast="9.2.7"
export qtkeychain="0.14"
export libgoogle_cloud_all_devel="2.24"
export gsoap="2.8.123"
export netcdf_cxx4="4.3"
export soapysdr="0.8"
export libgoogle_cloud_bigtable_devel="2.24"
export glog="0.6"
export sox="14.4.2"
export gdal="3.8"
export postgresql="16"
export pcre="8"
export antic="0.2"
export r_base="4.3.*"
export ncurses="6"
export libopencv="4.9.0"
export flann="1.9.2"
export libgoogle_cloud_devel="2.24"
export gdk_pixbuf="2"
export ipopt="3.14.16"
export msgpack_c="6"
export suitesparse="5"
export re2="2023.09.01"
export flatbuffers="24.3.25"
export ruby="2.5"
export graphviz="9"
export x264="1!164.*"
export openssl="3"
export libboost_devel="1.82"
export libgoogle_cloud="2.24"
export libkml="1.3"
export fmt="10"
export libsentencepiece="0.2.0"
export tensorflow="2.15"
export libzip="1"
export libvips="8"
export libgoogle_cloud_policytroubleshooter_devel="2.24"
export netcdf_fortran="4.6"
export geotiff="1.7.1"
export liblapack="3.9 *netlib"
export aws_c_s3="0.5.9"
export arrow_cpp="16"
export libarrow_all="16.1"
export libarrow="16.1"
export fortran_compiler_version="12"
export c_compiler_version="12"
export cxx_compiler_version="12"
export python_impl="cpython"
export cdt_name="cos6"
export c_stdlib_version="2.17"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/opt/conda/conda-bld/isoquant_1724750465066/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/conda/bin/python' -m conda shell.bash hook)"
conda activate  "/opt/conda/conda-bld/isoquant_1724750465066/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"

==> isoquant-3.5.2-hdfd78af_0.tar.bz2: share/isoquant-3.5.2-0/build_env_setup.sh <==
export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export ARCH="64"
export PREFIX="/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export BUILD_PREFIX="/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export SYS_PREFIX="/opt/conda"
export SYS_PYTHON="/opt/conda/bin/python"
export SUBDIR="linux-64"
export build_platform="linux-64"
export SRC_DIR="/opt/conda/conda-bld/isoquant_1725376915603/work"
export ROOT="/opt/conda"
export CONDA_PY="312"
export PY3K="1"
export PY_VER="3.12"
export STDLIB_DIR="/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.12"
export SP_DIR="/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.12/site-packages"
export NPY_VER="1.26"
export CONDA_NPY="126"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.32"
export CONDA_PERL="5.32"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="4.3.*"
export CONDA_R="4.3.*"
export PKG_NAME="isoquant"
export PKG_VERSION="3.5.2"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/opt/recipe"
export CPU_COUNT="2"
export LANG="C.UTF-8"
export SHLIB_EXT=".so"
export PATH="/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin:/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin:/opt/conda/bin:/opt/conda/condabin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/home/conda/bin"
export HOME="/home/conda"
export PKG_CONFIG_PATH="/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export LD_RUN_PATH="/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib"
export BUILD="x86_64-conda_cos6-linux-gnu"
export ignore_build_only_deps="{'python', 'numpy'}"
export pin_run_as_build="OrderedDict([('python', {'min_pin': 'x.x', 'max_pin': 'x.x'}), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('flann', {'max_pin': 'x.x.x'}), ('graphviz', {'max_pin': 'x'}), ('libsvm', {'max_pin': 'x'}), ('netcdf-cxx4', {'max_pin': 'x.x'}), ('occt', {'max_pin': 'x.x'}), ('poppler', {'max_pin': 'x.x'}), ('vlfeat', {'max_pin': 'x.x.x'})])"
export zip_keys="[['python', 'numpy', 'python_impl'], ['arrow_cpp', 'libarrow', 'libarrow_all'], ['c_compiler_version', 'cxx_compiler_version', 'fortran_compiler_version'], ['c_stdlib_version', 'cdt_name']]"
export extend_keys="{'ignore_build_only_deps', 'pin_run_as_build', 'ignore_version', 'extend_keys'}"
export tbb="2021"
export scotch="7.0.4"
export suitesparse="5"
export libgoogle_cloud_aiplatform_devel="2.24"
export arb="2.23"
export msgpack_c="6"
export libpcap="1.10"
export hdf4="4.2.15"
export libgoogle_cloud_compute_devel="2.24"
export rocksdb="9.1"
export expat="2"
export zeromq="4.3.5"
export console_bridge="1.0"
export giflib="5.2"
export soapysdr="0.8"
export nlopt="2.7"
export ntl="11.4.3"
export tk="8.6"
export xz="5"
export gsoap="2.8.123"
export cudnn="8"
export libsndfile="1.2"
export libtensorflow_cc="2.15"
export libgoogle_cloud_dialogflow_es_devel="2.24"
export json_c="0.17"
export orc="2.0.1"
export libxsmm="1"
export vlfeat="0.9.21"
export mpg123="1.32"
export libgit2="1.8"
export cfitsio="4.3.0"
export tinyxml2="10"
export aws_c_common="0.9.19"
export target_platform="linux-64"
export libraw="0.21"
export nspr="4"
export svt_av1="2.1.0"
export pulseaudio="17.0"
export poco="1.13.3"
export lmdb="0.9.29"
export libhugetlbfs="2"
export zlib="1.2"
export libhwloc="2.10.0"
export mkl_devel="2023"
export dbus="1"
export libaec="1"
export snappy="1.2"
export pugixml="1.14"
export sdl2="2"
export channel_targets="bioconda main"
export petsc="3.21"
export libabseil="20240116"
export libblas="3.9 *netlib"
export libduckdb_devel="0.9.2"
export aws_c_s3="0.5.9"
export libvips="8"
export bzip2="1"
export tiledb="2.23"
export cxx_compiler="gxx"
export curl="8"
export graphviz="9"
export zlib_ng="2.0"
export geos="3.12.1"
export tbb_devel="2021"
export google_cloud_cpp="2.24"
export urdfdom="4.0"
export cairo="1"
export root_base="6.28.10"
export google_cloud_cpp_common="0.25.0"
export sdl2_ttf="2"
export aws_crt_cpp="0.26.9"
export lz4_c="1.9.3"
export openexr="3.2"
export libptscotch="7.0.4"
export aws_c_auth="0.7.22"
export slepc4py="3.21"
export gflags="2.2"
export occt="7.7.2"
export libmatio="1.5.26"
export libsoup="3"
export libgoogle_cloud_spanner_devel="2.24"
export gfal2="2.22"
export libgdal="3.8"
export dcap="2.47"
export isl="0.26"
export idyntree="12"
export gmp="6"
export lzo="2"
export p11_kit="0.24"
export s2n="1.4.15"
export wcslib="8"
export spdlog="1.12"
export libgoogle_cloud_speech_devel="2.24"
export kealib="1.5"
export zstd="1.5"
export qt="5.15"
export geotiff="1.7.1"
export aom="3.8"
export coin_or_clp="1.17"
export harfbuzz="8"
export libgoogle_cloud_bigquery_devel="2.24"
export pybind11_abi="4"
export cran_mirror="https://cran.r-project.org"
export readline="8"
export ccr="1.3"
export aws_c_event_stream="0.4.2"
export libgoogle_cloud_automl_devel="2.24"
export aws_c_compression="0.2.18"
export libjpeg_turbo="3"
export gst_plugins_base="1.22"
export flann="1.9.2"
export libarchive="3.7"
export c_blosc2="2.14"
export alsa_lib="1.2"
export openmpi="4"
export VERBOSE_AT="V=1"
export jsoncpp="1.9.5"
export libprotobuf="4.25.3"
export glog="0.6"
export pcl="1.14.0"
export pcre2="10.43"
export glew="2.1"
export singular="4.3.2.p8"
export pytorch="2.1"
export libgoogle_cloud_pubsub_devel="2.24"
export poppler="24.04"
export xrootd="5"
export libgrpc="1.62"
export libgoogle_cloud_discoveryengine_devel="2.24"
export fortran_compiler="gfortran"
export libsvm="332"
export thrift_cpp="0.18.1"
export metis="5.1.0"
export gstreamer="1.22"
export postgresql_plpython="16"
export openjpeg="2"
export libframel="8.41"
export glib="2"
export vtk="9.2.6"
export libiio="0"
export ipopt="3.14.16"
export libgoogle_cloud_bigtable_devel="2.24"
export ruby="2.5"
export openh264="2.4.1"
export pixman="0"
export x264="1!164.*"
export libthrift="0.20.0"
export libmed="4.1"
export librsvg="2"
export aws_c_http="0.8.1"
export libintervalxt="3"
export coin_or_cbc="2.10"
export srm_ifce="1.24.6"
export x265="3.5"
export openssl="3"
export target_goarch="amd64"
export wxwidgets="3.2"
export gf2x="1.3"
export libcint="5.5"
export liblapacke="3.9 *netlib"
export log4cxx="1.2.0"
export krb5="1.21"
export re2="2023.09.01"
export mpfr="4"
export libopenvino_dev="2024.1.0"
export libgoogle_cloud="2.24"
export sqlite="3"
export superlu_dist="8"
export libgoogle_cloud_storage_devel="2.24"
export attr="2.5"
export libzip="1"
export mpich="4"
export libopencv="4.9.0"
export libkml="1.3"
export libhwy="1.1"
export arpack="3.8"
export libopentelemetry_cpp="1.15"
export antic="0.2"
export qtkeychain="0.14"
export libmicrohttpd="1.0"
export libexactreal="4"
export mumps_mpi="5.7.1"
export libwebp_base="1"
export fftw="3"
export exiv2="0.28"
export libosqp="0.6.3"
export capnproto="1.0.2"
export gnuradio_core="3.10.10"
export jpeg="9"
export libavif="1"
export libblitz="1.0.2"
export tensorflow="2.15"
export libsecret="0.18"
export libmatio_cpp="0.2.5"
export pyqt="5.15"
export libpng="1.6"
export lcms2="2"
export eclib="20231211"
export flatbuffers="24.3.25"
export gsl="2.7"
export coin_or_utils="2.11"
export pango="1.50"
export netcdf_fortran="4.6"
export cutensor="2"
export libgoogle_cloud_dlp_devel="2.24"
export libwebp="1"
export sox="14.4.2"
export libdeflate="1.20"
export cuda_compiler_version_min="11.8"
export go_compiler="go-nocgo"
export mumps_seq="5.7.1"
export abseil_cpp="20220623.0"
export pyqtwebengine="5.15"
export VERBOSE_CM="VERBOSE=1"
export libcurl="8"
export libsqlite="3"
export libsentencepiece="0.2.0"
export googleapis_cpp="0.10"
export librdkafka="2.4"
export libiconv="1"
export libscotch="7.0.4"
export icu="73"
export qt6_main="6.7"
export mkl="2023"
export libidn2="2"
export libflint="2.9"
export starlink_ast="9.2.7"
export pulseaudio_client="17.0"
export qt_main="5.15"
export libgoogle_cloud_dialogflow_cx_devel="2.24"
export libgoogle_cloud_devel="2.24"
export nodejs="18"
export bullet_cpp="3.25"
export libunwind="1.6"
export libgoogle_cloud_policytroubleshooter_devel="2.24"
export c_ares="1"
export rdma_core="51"
export openslide="4"
export libev="4.33"
export proj="9.3.1"
export elfutils="0.191"
export sdl2_image="2"
export aws_sdk_cpp="1.11.267"
export petsc4py="3.21"
export postgresql="16"
export xerces_c="3.2"
export aws_c_io="0.14.8"
export mimalloc="2.1.7"
export libboost_devel="1.82"
export openblas="0.3.*"
export msgpack_cxx="6"
export pari="2.15.* *_pthread"
export libgoogle_cloud_oauth2_devel="2.24"
export libcrc32c="1.1"
export libcblas="3.9 *netlib"
export dav1d="1.2.1"
export r_base="4.3.*"
export libeantic="2"
export _libgcc_mutex="0.1 conda_forge"
export libspatialindex="1.9.3"
export slepc="3.21"
export gdk_pixbuf="2"
export aws_c_cal="0.6.14"
export c_compiler="gcc"
export cuda_compiler_version="None"
export sdl2_net="2"
export libffi="3.4"
export coin_or_cgl="0.60"
export cgo_compiler="go-cgo"
export glpk="5.0"
export libdap4="3.20.6"
export zfp="1.0"
export gnutls="3.7"
export bamtools="2.5.2"
export libtensorflow="2.15"
export ptscotch="7.0.4"
export volk="3.1"
export nccl="2"
export gdal="3.8"
export freetype="2"
export imath="3.1.11"
export libflatsurf="3"
export libuuid="2"
export pcre="8"
export libv8="8.9.83"
export libtorch="2.1"
export libevent="2.1.12"
export c_stdlib="sysroot"
export target_goos="linux"
export jasper="4"
export cpu_optimization_target="nocona"
export target_gobin="${PREFIX}/bin/"
export libgoogle_cloud_all_devel="2.24"
export lerc="4"
export libtiff="4.6"
export libpq="16"
export fontconfig="2"
export fmt="10"
export libssh="0.10"
export ldas_tools_framecpp="2.9"
export netcdf_cxx4="4.3"
export pyqtchart="5.15"
export libyarp="3.9.0"
export libode="0.16.2"
export libssh2="1"
export coincbc="2.10"
export libboost_python_devel="1.82"
export assimp="5.3.1"
export aws_c_sdkutils="0.1.16"
export grpc_cpp="1.52"
export aws_c_mqtt="0.10.4"
export libabseil_static="20220623.0"
export libgoogle_cloud_iam_devel="2.24"
export sdl2_mixer="2"
export nettle="3.9"
export libxml2="2"
export pulseaudio_daemon="17.0"
export ffmpeg="6"
export aws_checksums="0.1.18"
export libnetcdf="4.9.2"
export ncurses="6"
export blas_impl="mkl"
export cuda_compiler="None"
export hdf5="1.14.3"
export rust_compiler="rust"
export liblapack="3.9 *netlib"
export gct="6.2.1705709074"
export channel_sources="conda-forge,bioconda"
export coin_or_osi="0.108"
export nss="3"
export davix="0.8"
export uhd="4.6.0"
export ucx="1.16.0"
export python_impl="cpython"
export c_compiler_version="12"
export fortran_compiler_version="12"
export cxx_compiler_version="12"
export c_stdlib_version="2.17"
export cdt_name="cos6"
export libarrow_all="15"
export arrow_cpp="15"
export libarrow="15"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/opt/conda/conda-bld/isoquant_1725376915603/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/conda/bin/python' -m conda shell.bash hook)"
conda activate  "/opt/conda/conda-bld/isoquant_1725376915603/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
